@@ -69,13 +69,23 @@ CREATE TABLE note (
   note   TEXT NOT NULL
 );
 
+SQL
+
+
+    $dbh->do( <<SQL );
+CREATE TABLE two_note (
+  id     INTEGER NOT NULL,
+  two_note_id INTEGER PRIMARY KEY NOT NULL,
+  note   TEXT NOT NULL
+);
+
 SQL
 
 
     $dbh->do( <<SQL );
 CREATE TABLE user (
   id     INTEGER PRIMARY KEY NOT NULL,
-  master INTEGER NOT NULL,
+  master INTEGER,
   name   TEXT NOT NULL,
   title  TEXT
 );
@@ -97,6 +107,7 @@ SQL
 CREATE TABLE user_band (
   user INTEGER NOT NULL,
   band INTEGER NOT NULL,
+  rating INTEGER,
   PRIMARY KEY (user, band)
 );
 
@@ -166,6 +177,17 @@ CREATE TABLE manager (
 
 SQL
 
+    $dbh->do( <<SQL );
+CREATE TABLE task (
+  id  INTEGER PRIMARY KEY NOT NULL,
+  schedule INTEGER NOT NULL,
+  deadline DATETIME,
+  detail   TEXT NOT NULL
+);
+
+SQL
+
+
 }
 
 
